| smle_ph | R Documentation |
Fit the proportional hazards model with maximum full likelihood estimation. Sieve estimation is used for estimating the baseline hazard function.
smle_ph(y, d, x)
y |
n-vector of survival time (> 0). |
d |
n-vector of right-censoring indicator, |
x |
p-dimensional matrix of covariates. |
see Choi et al., (2026+) for detailed method explanation.
smle_ph returns a list containing the following components:
Coef: regression estimator and its inferential results.
Cum.hazard: baseline cumulative hazard function estimates.
Choi et al., (2026+) Residual-Based Sieve Maximum Full Likelihood Estimation for the Proportional Hazards Model
library(smlePH)
set.seed(111)
n = 200
beta = c(1, -1, 0.5, -0.5, 1)
p = length(beta)
beta = matrix(beta, ncol = 1)
R = matrix(c(rep(0, p^2)), ncol = p)
diag(R) = 1
mu = rep(0, p)
SD = rep(1, p)
S = R * (SD %*% t(SD))
x = MASS::mvrnorm(n, mu, S)
T = (-log(runif(n)) / (2 * exp(x %*% beta)))^(1/2)
C = runif(n, min = 0, max = 2.9)
y = apply(cbind(T,C), 1, min)
d = (T <= C)+0
ord = order(y)
y = y[ord]; x = x[ord,]; d = d[ord]
smle_ph(y = y, d = d, x = x)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.