| smle_resid | R Documentation |
This function extracts residuals of the full likelihood proportional hazards model estimated by the sieve estimation. Deviance-type and score-type residuals are available.
smle_resid(y, d, x, fit, type = c("score", "deviance"))
y |
survival time (> 0). |
d |
right-censoring indicator, |
x |
p-dimensional covariates matrix. |
fit |
an object comes from the function |
type |
type of residual, either |
see Choi et al., (2026+) for detailed method explanation.
smle_resid returns a numeric vector (if type = "deviance") or a matrix (if type = "score") of residuals extracted from the object.
Choi et al., (2026+) Residual-Based Sieve Maximum Full Likelihood Estimation for the Proportional Hazards Model
library(smlePH)
# The 'fit' comes from an example description of smle_ph()
smle_resid(y = y, d = d, x = x, fit = fit, type = "deviance")
smle_resid(y = y, d = d, x = x, fit = fit, type = "score")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.